@@ -62,7 +62,7 @@ POOL_STATUS CommandComplete(POOL_CONNECTION *frontend, POOL_CONNECTION_POOL *bac
 	/*
 	 * Handle misc process which is neccessary when query context exists.
 	 */
-	if (session_context->query_context != NULL && !STREAM)
+	if (session_context->query_context != NULL && (!STREAM || (SL_MODE && !pool_is_doing_extended_query_message())))
 		handle_query_context(backend);
 
 	/*
@@ -72,6 +72,8 @@ POOL_STATUS CommandComplete(POOL_CONNECTION *frontend, POOL_CONNECTION_POOL *bac
 	 */
 	if (STREAM && pool_is_doing_extended_query_message())
 	{
+		p1 = NULL;
+
 		for (i=0;i<NUM_BACKENDS;i++)
 		{
 			if (VALID_BACKEND(i))
@@ -79,7 +81,11 @@ POOL_STATUS CommandComplete(POOL_CONNECTION *frontend, POOL_CONNECTION_POOL *bac
 				con = CONNECTION(backend, i);
 
 				if (pool_read(con, &len, sizeof(len)) < 0)
+				{
+					if (p1 != NULL)
+						pfree(p1);
 					return POOL_END;
+				}
 
 				len = ntohl(len);
 				len -= 4;
@@ -87,7 +93,13 @@ POOL_STATUS CommandComplete(POOL_CONNECTION *frontend, POOL_CONNECTION_POOL *bac
 
 				p = pool_read2(con, len);
 				if (p == NULL)
+				{
+					if (p1 != NULL)
+						pfree(p1);
 					return POOL_END;
+				}
+				if (p1 != NULL)
+					pfree(p1);
 				p1 = palloc(len);
 				memcpy(p1, p, len);
 
