@@ -1677,7 +1677,8 @@ static void pool_reset_memqcache_buffer(void)
 		 * if the query context is still under use, we cannot discard
 		 * temporary cache.
 		 */
-		if (can_query_context_destroy(session_context->query_context))
+		if ((SL_MODE && pool_is_doing_extended_query_message()) ||
+			can_query_context_destroy(session_context->query_context))
 		{
 			ereport(DEBUG1,
 				(errmsg("memcache reset buffer"),
@@ -2819,10 +2820,11 @@ void pool_discard_temp_query_cache(POOL_TEMP_QUERY_CACHE *temp_cache)
 		pool_discard_buffer(temp_cache->buffer);
 	if (temp_cache->oids)
 		pool_discard_buffer(temp_cache->oids);
-	pfree(temp_cache);
 
 	ereport(DEBUG1,
 			(errmsg("pool_discard_temp_query_cache: cache discarded: %p", temp_cache)));
+
+	pfree(temp_cache);
 }
 
 /*
@@ -3365,6 +3367,7 @@ void pool_handle_query_cache(POOL_CONNECTION_POOL *backend, char *query, Node *n
 					 * if DML/DDL modifies the TABLE which SELECT uses.
 					 */
 					pool_check_and_discard_cache_buffer(num_oids, oids);
+					pool_reset_memqcache_buffer();
 				} 
 			}
 			else if (num_oids == 0)
